import request from '@/config/axios'

// 商户 VO
export interface MerchantVO {
  // 商户id
  id: number
  // 商户名称
  name: string
  // 商户状态，关联商户状态表
  status: number
  // 简介
  description: string
  // 负责人
  contact: string
  // 所在地
  address: string
  // 负责人电话
  contactNumber: string
  // 官网
  website: string
  // 维权电话
  complaintsHotline: string
  // 客服电话
  customerServiceHotline: string
  // 邮箱
  email: string
  // 营业执照图片路径
  businessLicensePicture: string
  // 服务到期时间
  expireTime: Date
}

// 商户 API
export const MerchantApi = {
  // 查询商户分页
  getMerchantPage: async (params: any) => {
    return await request.get({ url: `/sale/merchant/page`, params })
  },

  // 查询商户详情
  getMerchant: async (id: number) => {
    return await request.get({ url: `/sale/merchant/get?id=` + id })
  },

  // 新增商户
  createMerchant: async (data: MerchantVO) => {
    return await request.post({ url: `/sale/merchant/create`, data })
  },

  // 修改商户
  updateMerchant: async (data: MerchantVO) => {
    return await request.put({ url: `/sale/merchant/update`, data })
  },

  // 删除商户
  deleteMerchant: async (id: number) => {
    return await request.delete({ url: `/sale/merchant/delete?id=` + id })
  },

  // 导出商户 Excel
  exportMerchant: async (params) => {
    return await request.download({ url: `/sale/merchant/export-excel`, params })
  },
  // 获取商户下的所有人员列表
  getAllUserByMer: async (id: number) => {
    return await request.get({ url: `/sale/shop/getAllUserByMer?merId=` + id })
  },
}